/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.test.webservice.secure;

// $Id: SimpleClientSecureTestCase.java,v 1.1.2.2 2005/07/27 12:50:01 tdiesler Exp $

import java.io.File;

import javax.naming.Context;
import javax.xml.rpc.Service;
import javax.xml.rpc.Stub;

import junit.framework.Test;

import org.jboss.test.webservice.WebserviceTestBase;
import org.jboss.test.webservice.ws4eesimple.HelloWs;

/**
 * Tests of the ws4ee functionality for a simple Hello EJB.
 *
 * @author Thomas.Diesler@jboss.org
 * @since 06-May-2004
 */
public class SimpleClientSecureTestCase extends WebserviceTestBase
{

   /**
    * Construct the test case with a given name
    */
   public SimpleClientSecureTestCase(String name)
   {
      super(name);
   }

   /**
    * deploy the test archives
    */
   public static Test suite() throws Exception
   {
      return getDeploySetup(SimpleClientSecureTestCase.class, "ws4ee-simple-secure.war, ws4ee-simple-secure-client.jar");
   }

   /**
    * Test client application access
    */
   public void testWithTransportOptions() throws Exception
   {
      Context envCtx = getClientContext();
      Service service = (Service)envCtx.lookup("java:comp/env/service/HelloWsSecureService");
      HelloWs port = (HelloWs)service.getPort(HelloWs.class);

      String keystore = "resources/test-configs/webservice-ssl/conf/client.keystore";
      assertTrue("Cannot find keystore", new File(keystore).exists());
      
      Stub stub = (Stub)port;
      stub._setProperty("keyStore", keystore);
      stub._setProperty("keyStorePassword", "unit-tests-client");
      stub._setProperty("keyStoreType", "JKS");
      stub._setProperty("trustStore", keystore);
      stub._setProperty("trustStorePassword", "unit-tests-client");
      stub._setProperty("trustStoreType", "JKS");

      String res = port.sayHello("Hello");
      assertEquals("'Hello' to you too!", res);
   }

   public void testWithoutTransportOptions() throws Exception
   {
      Context envCtx = getClientContext();
      Service service = (Service)envCtx.lookup("java:comp/env/service/HelloWsSecureService");
      HelloWs port = (HelloWs)service.getPort(HelloWs.class);

      String res = port.sayHello("Hello");
      assertEquals("'Hello' to you too!", res);
   }
}
